@@ -89,8 +89,6 @@ static gboolean exiting = FALSE;        /* threads should read this before
                                          * to true at cmd_exit() */
 static gboolean read_console = FALSE;   /* flag to turn on/off reading the
                                          * /dev/vcs* files */
-static gboolean show_textbox_area = FALSE;      /* flag to toggle showing
-                                                 * textbox area */
 static gboolean switched_to_verbose = FALSE;    /* flag to know when verbose
                                                  * image is displayed */
 static gboolean F2_toggle_pressed = FALSE;      /* keeps track of the depress 
@@ -117,53 +115,6 @@ splashy_chvt (gint vt_no)
         close (fd);
 }
 
-inline gboolean
-test_env_pattern (const gchar * perr_pattern, const gchar * filename)
-{
-        regex_t preg;
-        gint max_buf = 1024;    /* we need at least this number of characters 
-                                 * to check */
-        gboolean ret = FALSE;   /* assumes we will fail */
-        if (!g_file_test (filename, G_FILE_TEST_EXISTS))
-        {
-                ERROR_PRINT ("Cannot test file %s\n", filename);
-                return FALSE;
-        }
-        FILE *fp;
-        gchar *buffer = g_try_malloc (max_buf);
-        if (buffer && (fp = g_fopen (filename, "r")))
-        {
-                fread_unlocked (buffer, max_buf, 1, fp);        /* *_unlocked 
-                                                                 * are a GNU
-                                                                 * extension: 
-                                                                 * makes
-                                                                 * function
-                                                                 * fread()
-                                                                 * thread
-                                                                 * safe */
-                fclose (fp);
-                buffer[max_buf - 1] = '\0';
-                if (regcomp (&preg, perr_pattern,
-                             REG_EXTENDED | REG_ICASE | REG_NEWLINE |
-                             REG_NOSUB) == 0)
-                {
-                        if (regexec (&preg, buffer, 0, NULL, 0) == 0)
-                        {
-                                ret = TRUE;
-                        }
-                        else
-                        {
-                                g_printerr
-                                        ("WARN: %s was not found in %s. Did you append vga=0x317 to your kernel parameters? See README for more\n",
-                                         perr_pattern, filename);
-                        }
-                        regfree (&preg);
-                }
-        }
-        if (buffer)
-                g_free (buffer);
-        return ret;
-}
 /**
  * @desc looks for pattern in string ignoring known failure text messages
  * @param perr_pattern a valid regular expression pattern. @see man regex
@@ -364,6 +315,13 @@ cmd_print (void **args)
         return 0;
 }
 
+gint
+cmd_print_scroll (void **args)
+{
+        splashy_printline_s (args[0]);
+        return 0;
+}
+
 gint
 cmd_print_clear (void **args)
 {
@@ -468,12 +426,16 @@ struct
         {
         .cmd = "print",.handler = cmd_print,.args = 1,.specs = "s"},
         {
-        .cmd = "TEXT",.handler = cmd_print,.args = 1,.specs = "s"},
+        .cmd = "TEXT",.handler = cmd_print,.args = 1,.specs = "s"}, 
+        {
+        .cmd = "scroll",.handler = cmd_print_scroll,.args = 1,.specs = "s"},
+        {
+        .cmd = "SCROLL",.handler = cmd_print_scroll,.args = 1,.specs = "s"},
         {
         .cmd = "CLEAR",.handler = cmd_print_clear,.args =
                         0,.specs = NULL},
         {
-        .cmd = "clrprint",.handler = cmd_print_clear,.args =
+        .cmd = "clear",.handler = cmd_print_clear,.args =
                         0,.specs = NULL},
         {
         .cmd = "chvt",.handler = cmd_chvt,.args = 1,.specs = "d"},
@@ -672,9 +634,8 @@ _switch_to_verbose_image ()
 }
 
 /**
- * When pressing F2, or when autoverboseonerror is set
- * we show the scrolling UNIX text from the console /dev/vcs1, in a smaller window
- * if the user needs to type something, s/he must press ESC to exit Splashy
+ * When autoverboseonerror is set we show the scrolling 
+ * text from the consoles /dev/vcs*
  * @param data - not used
  * @return
  *
@@ -698,8 +659,8 @@ verbose_text_loop (void *data)
 
         dev_vcs = NULL;
         switched_to_verbose = FALSE;    /* verbose image flag */
-        show_textbox_area = FALSE;      /* when this flag is set we display a 
-                                         * textbox */
+        splashy_set_textbox_area_visible(FALSE);
+
         autoverbose = FALSE;    /* assume we don't need verbose mode for now */
         read_console = TRUE;    /* assume we will be able to read from a
                                  * console */
@@ -816,7 +777,7 @@ verbose_text_loop (void *data)
                                  * look for error messages only if we weren't asked
                                  * to display text right the way
                                  */
-                                if (show_textbox_area != TRUE)
+                                if (splashy_get_textbox_area_visible() != TRUE)
                                 {
                                         /*
                                          * we only look for errors if autoverbose
@@ -836,7 +797,7 @@ verbose_text_loop (void *data)
                                                                  buf, 1);
                                                 }
 
-                                                /* when the user press F2 we want to show
+                                                /* when the user presses F2 we want to show
                                                  * the buffer in the textbox anyway. regardless
                                                  * of whether an error was found or not */
                                                 if (F2_toggle_pressed != TRUE)
@@ -852,7 +813,7 @@ verbose_text_loop (void *data)
                                                  * and allow the textbox area to be shown
                                                  */
                                                 found_error = TRUE;
-                                                show_textbox_area = TRUE;
+                                                splashy_set_textbox_area_visible(TRUE);
 
                                                 if (autoverbose == TRUE
                                                     && switched_to_verbose ==
@@ -874,7 +835,7 @@ verbose_text_loop (void *data)
 
                                 /*
                                  * pressing F2 will cause text to be printed to the textbox
-                                 * as well as having autoverbose set to on in the config.xml
+                                 * as well as having autoverbose set to ON in the config.xml
                                  */
                                 if (autoverbose == TRUE
                                     || F2_toggle_pressed == TRUE)
@@ -1114,14 +1075,12 @@ keyevent_loop (void *data)
 				if (F2_toggle_pressed != TRUE)
 				{
 					F2_toggle_pressed = TRUE;
-					show_textbox_area = TRUE;
-					/* now show the box */
-					splashy_printline_s ("");
+					splashy_set_textbox_area_visible(TRUE);
 				}
 				else
 				{
 					F2_toggle_pressed = FALSE;
-					show_textbox_area = FALSE;
+                                        splashy_set_textbox_area_visible(FALSE);
 					/*
 					 * pressing F2 also clears the 
 					 * switched_to_verbose flag
@@ -1168,11 +1127,11 @@ _splashy_child (const gchar * seq)
                                                  * to manage  our keyboard  
                                                  * events and SplashyClient */
 
-        gint thr_id_f;          /* Handles /dev/vcs1 text to be displayed to
+        /*gint thr_id_f;          * Handles /dev/vcs1 text to be displayed to
                                  * splashy overlay textbox ... when pressing
                                  * F2 we launch a thread to handle the
                                  * console text */
-        pthread_t p_thread_f;
+        /*pthread_t p_thread_f;*/
 
         gboolean _preview = FALSE;
 
@@ -1246,8 +1205,8 @@ _splashy_child (const gchar * seq)
          */
         thr_id_d = pthread_create (&p_thread_d, NULL, keyevent_loop, NULL);
 
-        thr_id_f =
-                pthread_create (&p_thread_f, NULL, verbose_text_loop, NULL);
+        /*thr_id_f =
+                pthread_create (&p_thread_f, NULL, verbose_text_loop, NULL);*/
 
         /*
          * Wait till thread is finished reading the socket... ie 'forever' 
